==> codeblocks_8.02.orig.tar.gz: codeblocks-8.02/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsslider.h <==
/*
* This file is part of wxSmith plugin for Code::Blocks Studio
* Copyright (C) 2006-2007  Bartlomiej Swiecki
*
* wxSmith is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* wxSmith is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
*
* $Revision: 4850 $
* $Id: wxsslider.h 4850 2008-01-29 21:45:49Z byo $
* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsslider.h $
*/

#ifndef WXSSLIDER_H
#define WXSSLIDER_H

#include "../wxswidget.h"

/** \brief Class for wxsSlider widget */
class wxsSlider: public wxsWidget
{
    public:

        wxsSlider(wxsItemResData* Data);

    private:

        virtual void OnBuildCreatingCode();
        virtual wxObject* OnBuildPreview(wxWindow* Parent,long Flags);
        virtual void OnEnumWidgetProperties(long Flags);

        int Value;
        int Min;
        int Max;
        int TickFrequency;
        int PageSize;
        int LineSize;
        int ThumbLength;
        int Tick;
        int SelMin;
        int SelMax;
};

#endif

==> codeblocks_13.12+dfsg.orig.tar.gz: codeblocks-13.12/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsslider.h <==
/*
* This file is part of wxSmith plugin for Code::Blocks Studio
* Copyright (C) 2006-2007  Bartlomiej Swiecki
*
* wxSmith is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* wxSmith is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
*
* $Revision: 7109 $
* $Id: wxsslider.h 7109 2011-04-15 11:53:16Z mortenmacfly $
* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxsslider.h $
*/

#ifndef WXSSLIDER_H
#define WXSSLIDER_H

#include "../wxswidget.h"

/** \brief Class for wxsSlider widget */
class wxsSlider: public wxsWidget
{
    public:

        wxsSlider(wxsItemResData* Data);

    private:

        virtual void OnBuildCreatingCode();
        virtual wxObject* OnBuildPreview(wxWindow* Parent,long Flags);
        virtual void OnEnumWidgetProperties(long Flags);

        long Value;
        long Min;
        long Max;
        long TickFrequency;
        long PageSize;
        long LineSize;
        long ThumbLength;
        long Tick;
        long SelMin;
        long SelMax;
};

#endif
